.. _automap_toplevel:

Automap
=======

.. automodule:: sqlalchemy.ext.automap

API Reference
-------------

.. autofunction:: automap_base

.. autoclass:: AutomapBase
	:members:

.. autofunction:: classname_for_table

.. autofunction:: name_for_scalar_relationship

.. autofunction:: name_for_collection_relationship

.. autofunction:: generate_relationship
